==> scilab_5.1.orig.tar.gz: scilab-5.1/modules/graphics/src/c/getHandleProperty/get_tics_direction_property.c <==
/*
 * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
 * Copyright (C) 2004-2006 - INRIA - Fabrice Leray
 * Copyright (C) 2006 - INRIA - Allan Cornet
 * Copyright (C) 2006 - INRIA - Jean-Baptiste Silvy
 * 
 * This file must be used under the terms of the CeCILL.
 * This source file is licensed as described in the file COPYING, which
 * you should have received as part of this distribution.  The terms
 * are also available at    
 * http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
 *
 */

/*------------------------------------------------------------------------*/
/* file: get_tics_direction_property.c                                    */
/* desc : function to retrieve in Scilab the tics_direction field of      */
/*        a handle                                                        */
/*------------------------------------------------------------------------*/

#include "getHandleProperty.h"
#include "GetProperty.h"
#include "returnProperty.h"
#include "Scierror.h"
#include "localization.h"

/*------------------------------------------------------------------------*/
int get_tics_direction_property( sciPointObj * pobj )
{
  if ( sciGetEntityType( pobj ) != SCI_AXES )
  {
    Scierror(999, _("%s property does not exist for this handle.\n"), "tics_direction") ;
    return -1 ;
  }

  switch ( pAXES_FEATURE (pobj)->dir )
  {
  case 'u': 
    return sciReturnString( "top" ) ;
    break;
  case 'd': 
    return sciReturnString( "bottom" ) ;
    break;
  case 'r': 
    return sciReturnString( "right" ) ;
    break;
  case 'l': 
    return sciReturnString( "left" ) ;
    break;
  default : 
    Scierror(999, _("%s is not correctly defined.\n"), "tics_direction") ;
    break;
  }
  return -1;

}
/*------------------------------------------------------------------------*/

==> scilab_5.3.1.orig.tar.gz: scilab-5.3.1/modules/graphics/src/c/getHandleProperty/get_tics_direction_property.c <==
/*
 * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
 * Copyright (C) 2004-2006 - INRIA - Fabrice Leray
 * Copyright (C) 2006 - INRIA - Allan Cornet
 * Copyright (C) 2006 - INRIA - Jean-Baptiste Silvy
 * 
 * This file must be used under the terms of the CeCILL.
 * This source file is licensed as described in the file COPYING, which
 * you should have received as part of this distribution.  The terms
 * are also available at    
 * http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
 *
 */

/*------------------------------------------------------------------------*/
/* file: get_tics_direction_property.c                                    */
/* desc : function to retrieve in Scilab the tics_direction field of      */
/*        a handle                                                        */
/*------------------------------------------------------------------------*/

#include "getHandleProperty.h"
#include "GetProperty.h"
#include "returnProperty.h"
#include "Scierror.h"
#include "localization.h"

/*------------------------------------------------------------------------*/
int get_tics_direction_property( sciPointObj * pobj )
{
  if ( sciGetEntityType( pobj ) != SCI_AXES )
  {
    Scierror(999, _("'%s' property does not exist for this handle.\n"), "tics_direction") ;
    return -1 ;
  }

  switch ( pAXES_FEATURE (pobj)->dir )
  {
  case 'u': 
    return sciReturnString( "top" ) ;
    break;
  case 'd': 
    return sciReturnString( "bottom" ) ;
    break;
  case 'r': 
    return sciReturnString( "right" ) ;
    break;
  case 'l': 
    return sciReturnString( "left" ) ;
    break;
  default : 
    Scierror(999, _("Wrong value for '%s' property.\n"),"tics_direction");
    break;
  }
  return -1;

}
/*------------------------------------------------------------------------*/
